/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/unittest/postgis/Utils.cpp

  \brief A Utils functions for  postgis unit test.

 */

// TerraLib
#include <terralib/dataaccess/datasource/DataSource.h>
#include <terralib/dataaccess/datasource/DataSourceFactory.h>
#include <terralib/postgis/Transactor.h>

#include "Utils.h"

// STL
#include <iostream>

std::unique_ptr<te::da::DataSource> GetPostGISConnection()
{
  // let's give the minimal server connection information needed to connect to
  // the database server
  std::string user, password, host, port, path, query;
  std::string strURI = "pgsql://"; // The base of the URI
  host = "localhost";
  port = "5432";
  user = "postgres";
  password = "postgres";
  path = "TerraLib5";
  query = "PG_CLIENT_ENCODING=" +
          te::core::CharEncoding::getEncodingName(te::core::EncodingType::UTF8);
  query += "&PG_CONNECT_TIMEOUT=4";

  strURI += user + ":";
  strURI += password + "@";
  strURI += host + ":";
  strURI += port + "/";
  strURI += path + "?";
  strURI += query;

  // create a data source using the data source factory
  std::unique_ptr<te::da::DataSource> ds = te::da::DataSourceFactory::make("POSTGIS", strURI);

  try
  {
    ds->open();
  }
  catch(const std::exception& e)
  {
    std::cout << "Datasource " << host << "/" << path
              << " can not be used!\nMake sure to have the correct connection "
                 "parameters\n";
    std::cout << "Error: " << e.what() << std::endl;
    ds.reset();
    return ds;
  }
  catch(...)
  {
    std::cout << "Datasource " << host << "/" << path
              << " can not be used!\nMake sure to have the correct connection "
                 "parameters\n";
    ds.reset();
    return ds;
  }

  std::cout << "Using datasource " << host << "/" <<  path << std::endl;
  ds->close();
  return ds;
}
